"use client";

import { GlassCard } from "@/components/ui/glass-card";
import { Button } from "@/components/ui/button";
import { useState, useRef, useEffect } from "react";

// 消息类型定义
interface Message {
  id: string;
  content: string;
  role: "user" | "assistant" | "system";
  timestamp: Date;
}

// 系统预设消息 - 定义AI助手的角色和功能
const SYSTEM_PROMPT = `你是"文献启明星"科研助手系统中的AI顾问，专为科研人员、学者和学生设计。
你的主要职责包括：
1. 解答学术和研究方法相关问题
2. 提供文献检索和分析建议
3. 解释复杂的科研概念和理论
4. 帮助分析研究方向和趋势
5. 辅助论文写作和结构规划

你拥有丰富的科研知识，可以帮助用户提高研究效率。在回答问题时，你应保持严谨、专业的态度，同时用友好的语气与用户交流。

文献启明星系统的主要功能：
- 文献研究：智能分析研究领域，生成研究方向报告，查找相关论文
- AI聊天：即你现在提供的服务，解答学术问题，提供研究建议
- 论文分析：自动提取论文关键信息，生成摘要和解读，推荐相关文献

请记住，你是用户科研工作的助手，目标是帮助他们更高效地完成研究工作。`;

// 添加重试逻辑
const fetchWithRetry = async (
  url: string, 
  options: RequestInit, 
  maxRetries = 3
): Promise<Response> => {
  let lastError;
  
  for (let i = 0; i < maxRetries; i++) {
    try {
      return await fetch(url, options);
    } catch (error) {
      console.log(`请求失败，尝试重试 ${i + 1}/${maxRetries}`);
      lastError = error;
      // 指数退避策略
      await new Promise(r => setTimeout(r, 1000 * Math.pow(2, i)));
    }
  }
  
  throw lastError;
};

export default function AIChatPage() {
  // 状态管理
  const [messages, setMessages] = useState<Message[]>([
    {
      id: "system-message",
      content: SYSTEM_PROMPT,
      role: "system",
      timestamp: new Date(),
    },
    {
      id: "welcome-message",
      content: "您好！我是文献启明星的AI研究助手。作为您的科研伙伴，我可以帮助您解答学术问题、分析研究方向、提供文献建议，以及辅助论文写作。请问今天有什么我可以协助您的研究工作吗？",
      role: "assistant",
      timestamp: new Date(),
    },
  ]);
  const [inputText, setInputText] = useState("");
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [visibleMessages, setVisibleMessages] = useState<Message[]>([]);
  
  const messagesEndRef = useRef<HTMLDivElement>(null);
  const chatContainerRef = useRef<HTMLDivElement>(null);
  
  // 过滤系统消息，只显示用户和助手的消息
  useEffect(() => {
    setVisibleMessages(messages.filter(msg => msg.role !== "system"));
  }, [messages]);
  
  // 自动滚动到最新消息
  useEffect(() => {
    if (messagesEndRef.current) {
      messagesEndRef.current.scrollIntoView({ behavior: "smooth" });
    }
  }, [visibleMessages]);
  
  // 发送消息
  const sendMessage = async () => {
    if (!inputText.trim() || isLoading) return;
    
    // 清除之前的错误
    setError(null);
    
    // 创建用户消息
    const userMessage: Message = {
      id: Date.now().toString(),
      content: inputText,
      role: "user",
      timestamp: new Date(),
    };
    
    // 更新消息列表
    setMessages(prev => [...prev, userMessage]);
    setInputText("");
    setIsLoading(true);
    
    // 添加超时控制
    const timeoutPromise = new Promise((_, reject) => {
      const now = new Date();
      const timeString = now.toLocaleTimeString(); // 获取当前时间
      setTimeout(() => 
        reject(new Error(`请求超时，请检查网络连接 [${timeString}]`)), 
        30000); // 30秒超时
    });
    
    try {
      // 准备发送到API的消息历史（包括系统消息）
      const apiMessages = messages
        .concat(userMessage)
        .map(msg => ({
          role: msg.role,
          content: msg.content
        }));
      
      // 使用Promise.race添加超时控制
      const response = await Promise.race([
        fetchWithRetry("/api/chat", {
          method: "POST",
          headers: { "Content-Type": "application/json" },
          body: JSON.stringify({ messages: apiMessages })
        }),
        timeoutPromise
      ]) as Response;
      
      if (!response.ok) {
        let errorMessage = "服务器错误";
        try {
          const errorData = await response.json();
          errorMessage = errorData.error || errorMessage;
        } catch (e) {
          // 解析JSON失败，使用默认错误消息
        }
        throw new Error(errorMessage);
      }
      
      const data = await response.json();
      
      // 创建AI回复消息
      const aiResponse: Message = {
        id: (Date.now() + 1).toString(),
        content: data.message?.content || 
                 (data.messages && data.messages.length > 0 ? 
                   data.messages[data.messages.length - 1].content : 
                   "抱歉，接收到了空响应"),
        role: "assistant",
        timestamp: new Date(),
      };
      
      setMessages(prev => [...prev, aiResponse]);
    } catch (err) {
      console.error("聊天请求失败:", err);
      
      // 获取具体的错误信息
      const errorMsg = err instanceof Error 
        ? err.message 
        : "与AI服务通信失败，请检查网络连接或后端服务是否正常运行";
      
      // 设置错误状态
      setError(errorMsg);
      
      // 添加用户友好的错误消息
      const errorMessage: Message = {
        id: (Date.now() + 1).toString(),
        content: `很抱歉，发生了错误：${errorMsg}。请稍后再试，或者联系管理员检查后端服务是否正常运行。`,
        role: "assistant",
        timestamp: new Date(),
      };
      
      setMessages(prev => [...prev, errorMessage]);
    } finally {
      setIsLoading(false);
    }
  };
  
  // 处理按Enter键发送
  const handleKeyPress = (e: React.KeyboardEvent) => {
    if (e.key === "Enter" && !e.shiftKey) {
      e.preventDefault();
      sendMessage();
    }
  };
  
  // 清空聊天记录
  const clearChat = () => {
    setMessages([
      {
        id: "system-message",
        content: SYSTEM_PROMPT,
        role: "system",
        timestamp: new Date(),
      },
      {
        id: "welcome-message",
        content: "聊天已重置。我是文献启明星的AI研究助手，请问有什么我可以帮助您的？",
        role: "assistant",
        timestamp: new Date(),
      }
    ]);
  };
  
  return (
    <main className="relative flex min-h-[calc(100vh-64px)] flex-col">
      <div className="container mx-auto px-4 pb-4 flex flex-col h-[calc(100vh-64px)]">
        {/* 标题区域 - 减小高度并固定在顶部 */}
        <div className="text-center py-4 flex justify-between items-center">
          <div className="flex-1"></div>
          <div className="flex-2 text-center">
            <h1 className="text-3xl font-bold text-center text-transparent bg-clip-text bg-gradient-to-r from-white to-white/70 drop-shadow-lg">
              AI 智能助手
            </h1>
            <p className="text-sm text-center text-white/80">
              您的个人研究与学习伙伴
            </p>
            <div className="w-12 h-1 mx-auto mt-2 bg-gradient-to-r from-[var(--theme-accent)] to-[var(--theme-highlight)] rounded-full"></div>
          </div>
          <div className="flex-1 flex justify-end">
            <button
              onClick={clearChat}
              className="text-white/70 hover:text-white text-sm py-1 px-3 rounded-md bg-white/10 hover:bg-white/20 transition-colors"
            >
              <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="inline-block mr-1">
                <path d="M3 6h18"></path>
                <path d="M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6"></path>
                <path d="M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2"></path>
              </svg>
              清空
            </button>
          </div>
        </div>
        
        {/* 聊天区域 - 占据大部分空间 */}
        <div className="flex-1 overflow-hidden flex flex-col">
          <GlassCard className="w-full flex-1 flex flex-col overflow-hidden">
            {/* 聊天消息区域 - 可滚动区域 */}
            <div 
              ref={chatContainerRef}
              className="flex-1 overflow-y-auto px-2 py-4 scroll-smooth" 
              style={{ 
                scrollbarWidth: 'thin',
                scrollbarColor: 'rgba(255,255,255,0.2) transparent'
              }}
            >
              <div className="space-y-6">
                {visibleMessages.map((message) => (
                  <div 
                    key={message.id} 
                    className={`flex items-start gap-3 ${message.role === "user" ? "justify-end" : ""}`}
                  >
                    {message.role === "assistant" && (
                      <div className="w-8 h-8 rounded-full bg-[var(--theme-accent)]/80 flex items-center justify-center text-white text-sm font-medium shrink-0 mt-1">AI</div>
                    )}
                    
                    <div className={`${
                      message.role === "assistant" 
                        ? "bg-white/10 backdrop-blur-sm rounded-lg rounded-tl-none" 
                        : "bg-[var(--theme-accent)]/20 backdrop-blur-sm rounded-lg rounded-tr-none"
                    } p-3 max-w-[85%]`}>
                      <p className="text-white/90 whitespace-pre-wrap break-words">{message.content}</p>
                    </div>
                    
                    {message.role === "user" && (
                      <div className="w-8 h-8 rounded-full bg-white/20 flex items-center justify-center text-white text-sm font-medium shrink-0 mt-1">您</div>
                    )}
                  </div>
                ))}
                
                {isLoading && (
                  <div className="flex items-start gap-3">
                    <div className="w-8 h-8 rounded-full bg-[var(--theme-accent)]/80 flex items-center justify-center text-white text-sm font-medium shrink-0">AI</div>
                    <div className="bg-white/10 backdrop-blur-sm p-3 rounded-lg rounded-tl-none">
                      <div className="flex space-x-2 items-center h-6">
                        <div className="w-2 h-2 rounded-full bg-white/70 animate-bounce"></div>
                        <div className="w-2 h-2 rounded-full bg-white/70 animate-bounce" style={{animationDelay: "0.2s"}}></div>
                        <div className="w-2 h-2 rounded-full bg-white/70 animate-bounce" style={{animationDelay: "0.4s"}}></div>
                      </div>
                    </div>
                  </div>
                )}
                
                {error && (
                  <div className="bg-red-500/20 p-3 rounded-lg text-white/90 text-sm mx-4">
                    <span className="font-medium">错误：</span> {error}
                  </div>
                )}
                
                {/* 用于自动滚动的空白元素 */}
                <div ref={messagesEndRef} />
              </div>
            </div>
            
            {/* 输入区域 - 固定在底部 */}
            <div className="p-4 border-t border-white/10">
              <div className="flex gap-2">
                <textarea 
                  className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50 resize-none h-16"
                  placeholder="输入您的科研问题或需求..."
                  value={inputText}
                  onChange={(e) => setInputText(e.target.value)}
                  onKeyDown={handleKeyPress}
                  disabled={isLoading}
                ></textarea>
                <Button 
                  className="self-end"
                  onClick={sendMessage}
                  disabled={isLoading || !inputText.trim()}
                >
                  <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
                    <path d="M22 2L11 13"></path>
                    <path d="M22 2L15 22L11 13L2 9L22 2Z"></path>
                  </svg>
                </Button>
              </div>
              <div className="mt-2 text-white/50 text-xs">
                提示：您可以询问学术问题、研究方向分析、文献推荐、论文写作建议等。按Enter发送，Shift+Enter换行。
              </div>
            </div>
          </GlassCard>
        </div>
        
        {/* 底部版权信息 */}
        <p className="text-white/50 text-center text-xs mt-2">
          基于DeepSeek AI的智能对话系统 | 文献启明星科研助手
        </p>
      </div>
    </main>
  );
} 