import { NextRequest, NextResponse } from 'next/server';

// 添加更多环境变量和错误处理
const BACKEND_API_URL = process.env.BACKEND_API_URL || process.env.NEXT_PUBLIC_BACKEND_API_URL || 'http://localhost:8000';
const API_TIMEOUT = parseInt(process.env.API_TIMEOUT || '30000', 10);

export async function POST(request: NextRequest) {
  try {
    const { messages } = await request.json();
    
    if (!messages || !Array.isArray(messages)) {
      return NextResponse.json(
        { error: '请求格式不正确' },
        { status: 400 }
      );
    }
    
    console.log(`使用后端API URL: ${BACKEND_API_URL}`);
    
    // 添加超时控制
    const controller = new AbortController();
    const timeoutId = setTimeout(() => controller.abort(), API_TIMEOUT);
    
    try {
      // 调用后端API
      const response = await fetch(`${BACKEND_API_URL}/api/chat`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ messages }),
        signal: controller.signal
      });
      
      clearTimeout(timeoutId);
      
      if (!response.ok) {
        let errorMsg = '与AI服务通信失败';
        try {
          const errorData = await response.json();
          console.error('后端API错误:', errorData);
          errorMsg = errorData.detail || errorData.message || errorMsg;
        } catch (e) {
          console.error('解析错误响应失败:', e);
        }
        
        return NextResponse.json(
          { error: errorMsg },
          { status: response.status }
        );
      }
      
      const data = await response.json();
      return NextResponse.json(data);
    } catch (fetchError: any) {
      clearTimeout(timeoutId);
      console.error('请求后端API失败:', fetchError);
      
      if (fetchError.name === 'AbortError') {
        return NextResponse.json(
          { error: '请求超时，后端服务可能未响应' },
          { status: 504 }
        );
      }
      
      throw fetchError;
    }
  } catch (error: any) {
    console.error('API路由错误:', error);
    return NextResponse.json(
      { error: '处理请求时发生错误', message: error.message || '未知错误' },
      { status: 500 }
    );
  }
} 