"use client";

import { useState } from 'react';
import { GlassCard } from "@/components/ui/glass-card";
import { Button } from "@/components/ui/button";
import Link from 'next/link';
import { useRouter } from 'next/navigation';

// API基础URL
const API_BASE_URL = process.env.NEXT_PUBLIC_API_URL || "http://localhost:8000/api";

// 在文件顶部添加类型定义
interface ApiError {
  message: string;
  response?: {
    status: number;
    data: any;
  };
}

export default function LoginPage() {
  const [username, setUsername] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const router = useRouter();
  
  const handleLogin = async (e: React.FormEvent) => {
    e.preventDefault();
    setError('');
    setIsLoading(true);
    
    try {
      console.log("开始登录流程...");
      
      // 创建FormData
      const formData = new FormData();
      formData.append('username', username);
      formData.append('password', password);
      
      // 登录请求
      console.log("发送登录请求到:", `${API_BASE_URL}/auth/token`);
      const response = await fetch(`${API_BASE_URL}/auth/token`, {
        method: 'POST',
        body: formData
      });
      
      // 检查响应状态
      console.log("登录请求状态:", response.status);
      if (!response.ok) {
        const errorText = await response.text();
        console.error("登录失败:", errorText);
        throw new Error('用户名或密码不正确');
      }
      
      const data = await response.json();
      console.log("登录成功，获取到token");
      
      // 保存token到localStorage
      localStorage.setItem('token', data.access_token);
      
      // 同时在cookie中设置token
      document.cookie = `token=${data.access_token}; path=/; max-age=86400`; // 设置为1天过期
      
      // 获取用户资料
      console.log("获取用户资料...");
      const userResponse = await fetch(`${API_BASE_URL}/users/profile`, {
        headers: {
          'Authorization': `Bearer ${data.access_token}`
        }
      });
      
      if (!userResponse.ok) {
        console.error("获取用户资料失败:", userResponse.status);
        throw new Error('登录成功但无法获取用户资料');
      }
      
      const userData = await userResponse.json();
      console.log("获取用户资料成功:", userData);
      localStorage.setItem('userData', JSON.stringify(userData));
      
      // 登录成功后
      console.log("登录成功，准备跳转...");
      
      // 直接使用window.location进行硬跳转
      window.location.href = '/profile';
      
      // 如果上面的方法不起作用，尝试设置超时
      setTimeout(() => {
        window.location.replace('/profile');
      }, 500);
    } catch (err) {
      const error = err as ApiError;
      console.error('登录过程出错:', error);
      
      if (error.response) {
        // 处理响应错误
        setError(error.response.data?.detail || `错误(${error.response.status})`);
      } else if (error.message) {
        setError(error.message);
      } else {
        setError('登录失败，请稍后再试');
      }
    } finally {
      setIsLoading(false);
    }
  };
  
  return (
    <main className="flex items-center justify-center min-h-screen p-4">
      <GlassCard className="w-full max-w-md">
        <h1 className="text-3xl font-bold text-center text-white mb-8">登录</h1>
        
        {error && (
          <div className="bg-red-500/20 p-3 mb-6 rounded-lg text-white">
            {error}
          </div>
        )}
        
        <form onSubmit={handleLogin} className="space-y-6">
          <div>
            <label className="block text-white/60 text-sm mb-2">用户名</label>
            <input 
              type="text"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={username}
              onChange={(e) => setUsername(e.target.value)}
              required
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">密码</label>
            <input 
              type="password"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              required
            />
          </div>
          
          <Button 
            type="submit" 
            className="w-full" 
            disabled={isLoading}
          >
            {isLoading ? (
              <div className="inline-block w-6 h-6 border-2 border-t-transparent border-white rounded-full animate-spin"></div>
            ) : '登录'}
          </Button>
        </form>
        
        <div className="mt-6 text-center">
          <p className="text-white/60">
            还没有账号？ 
            <Link href="/register" className="text-[var(--theme-accent)] hover:underline ml-1">
              注册
            </Link>
          </p>
        </div>
      </GlassCard>
    </main>
  );
} 