"use client";

import { GlassCard } from "@/components/ui/glass-card";
import { Button } from "@/components/ui/button";
import { useState, useEffect } from "react";
import Link from "next/link";
import { useSearchParams } from 'next/navigation';
import axios, { AxiosError } from "axios";

// 定义标签页
const tabs = [
  { id: "profile", label: "个人信息", icon: (
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
      <path d="M20 21v-2a4 4 0 0 0-4-4H8a4 4 0 0 0-4 4v2"></path>
      <circle cx="12" cy="7" r="4"></circle>
    </svg>
  ) },
  { id: "history", label: "使用记录", icon: (
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
      <path d="M12 8v4l3 3"></path>
      <circle cx="12" cy="12" r="10"></circle>
    </svg>
  ) },
  { id: "favorites", label: "收藏论文", icon: (
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
      <path d="m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z"></path>
    </svg>
  ) },
  { id: "settings", label: "系统设置", icon: (
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
      <path d="M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z"></path>
      <circle cx="12" cy="12" r="3"></circle>
    </svg>
  ) }
];

// 在文件顶部添加明确的类型定义
interface UserData {
  id: number;
  username: string;
  email: string;
  avatar: null | string;
  researchFields: string[];  // 明确定义为string[]
  membershipType: string;
  expiryDate: string;
  credits: number;
  registerDate: string;
  institution: string;
  position: string;
}

// API基础URL
const API_BASE_URL = process.env.NEXT_PUBLIC_API_URL || "http://localhost:8000/api";

export default function ProfilePage() {
  const searchParams = useSearchParams();
  const tabParam = searchParams.get('tab');
  
  // 当前激活的标签页
  const [activeTab, setActiveTab] = useState(tabParam || "profile");
  const [isDarkMode, setIsDarkMode] = useState(true);
  const [notificationSettings, setNotificationSettings] = useState({
    email: true,
    research: true,
    updates: true
  });
  const [privacySettings, setPrivacySettings] = useState({
    twoFactor: false,
    dataAnalysis: true
  });
  const [isEditing, setIsEditing] = useState(false);
  const [userData, setUserData] = useState<UserData>({
    id: 0,
    username: "加载中...",
    email: "loading@example.com",
    avatar: null,
    researchFields: [] as string[],  // 明确类型
    membershipType: "加载中...",
    expiryDate: "2025-12-31",
    credits: 0,
    registerDate: "-",
    institution: "江西财经大学",
    position: "学生"
  });
  const [editedUser, setEditedUser] = useState<UserData>({...userData});
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState("");
  const [chatHistory, setChatHistory] = useState([]);
  const [researchHistory, setResearchHistory] = useState([]);
  const [isLoggedIn, setIsLoggedIn] = useState(false); // 默认为未登录
  const [loginUsername, setLoginUsername] = useState('');
  const [loginPassword, setLoginPassword] = useState('');
  const [loginError, setLoginError] = useState('');
  
  // 每当URL参数变化时更新激活的标签页
  useEffect(() => {
    if (tabParam && tabs.some(tab => tab.id === tabParam)) {
      setActiveTab(tabParam);
    }
  }, [tabParam]);
  
  // 获取用户资料
  useEffect(() => {
    const fetchUserProfile = async () => {
      try {
        setIsLoading(true);
        // 从本地存储获取token
        const token = localStorage.getItem("token");
        
        if (!token) {
          // 没有token，表示未登录
          setIsLoggedIn(false);
          setIsLoading(false);
          
          // 检查URL是否来自中间件重定向（避免两次验证）
          const urlParams = new URLSearchParams(window.location.search);
          if (urlParams.has('redirect')) {
            // 如果是重定向来的，不要显示内嵌登录表单，而是直接跳转到登录页
            window.location.href = '/login?redirect=/profile';
            return;
          }
          
          return;
        }
        
        // 有token，尝试获取用户资料
        try {
          const response = await axios.get(`${API_BASE_URL}/users/profile`, {
            headers: {
              Authorization: `Bearer ${token}`
            }
          });
          
          // 如果请求成功，说明token有效
          setIsLoggedIn(true);
          
          // 处理后端返回的数据，转换字段名称从下划线到驼峰命名
          const responseData = response.data;
          
          // 添加字段映射逻辑
          const userData = {
            id: responseData.id,
            username: responseData.username,
            email: responseData.email,
            avatar: responseData.avatar,
            // 处理研究领域
            researchFields: responseData.research_fields || ["人工智能", "机器学习", "自然语言处理"],
            // 处理会员信息
            membershipType: responseData.membership_type || "免费用户",
            expiryDate: responseData.expiry_date || "未设置",
            credits: responseData.credits || 0,
            // 添加注册时间 - 可能需要从后端添加或使用创建时间
            registerDate: responseData.created_at || "-",
            institution: responseData.institution || "",
            position: responseData.position || ""
          };
          
          setUserData(userData);
          setEditedUser(userData);
        } catch (error) {
          // 如果请求失败，可能是token无效或已过期
          console.error("获取用户资料失败:", error);
          localStorage.removeItem("token"); // 清除无效token
          document.cookie = "token=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;"; // 清除cookie中的token
          setIsLoggedIn(false);
        }
        
        setIsLoading(false);
      } catch (err) {
        console.error("初始化用户资料失败:", err);
        setError("获取用户资料失败");
        setIsLoading(false);
        setIsLoggedIn(false);
      }
    };
    
    // 加载设置
    const loadSettings = () => {
      const storedNotificationSettings = localStorage.getItem("notificationSettings");
      if (storedNotificationSettings) {
        try {
          setNotificationSettings(JSON.parse(storedNotificationSettings));
        } catch (e) {
          console.error("解析通知设置失败:", e);
        }
      }
      
      const storedPrivacySettings = localStorage.getItem("privacySettings");
      if (storedPrivacySettings) {
        try {
          setPrivacySettings(JSON.parse(storedPrivacySettings));
        } catch (e) {
          console.error("解析隐私设置失败:", e);
        }
      }
    };
    
    fetchUserProfile();
    loadSettings();
  }, []);
  
  // 获取聊天历史
  useEffect(() => {
    const fetchChatHistory = async () => {
      if (activeTab !== "history") return;
      
      try {
        const token = localStorage.getItem("token");
        if (!token) return;
        
        const response = await axios.get(`${API_BASE_URL}/chat-history`, {
          headers: {
            Authorization: `Bearer ${token}`
          }
        });
        
        setChatHistory(response.data || []);
      } catch (err) {
        console.error("获取聊天历史失败:", err);
      }
    };
    
    fetchChatHistory();
  }, [activeTab]);
  
  // 获取研究历史
  useEffect(() => {
    const fetchResearchHistory = async () => {
      if (activeTab !== "history") return;
      
      try {
        const token = localStorage.getItem("token");
        if (!token) return;
        
        const response = await axios.get(`${API_BASE_URL}/research-history`, {
          headers: {
            Authorization: `Bearer ${token}`
          }
        });
        
        setResearchHistory(response.data || []);
      } catch (err) {
        console.error("获取研究历史失败:", err);
      }
    };
    
    fetchResearchHistory();
  }, [activeTab]);
  
  // 切换编辑模式
  const toggleEditMode = async () => {
    if (isEditing) {
      try {
        const token = localStorage.getItem("token");
        
        if (token) {
          // 显示加载状态
          setIsLoading(true);
          setError("");
          
          // 保存到API
          const response = await axios.put(`${API_BASE_URL}/users/profile`, {
            username: editedUser.username,
            email: editedUser.email,
            institution: editedUser.institution,
            position: editedUser.position,
            research_fields: editedUser.researchFields,
          }, {
            headers: {
              Authorization: `Bearer ${token}`
            }
          });
          
          // 更新本地状态
          setUserData(editedUser);
          localStorage.setItem("userData", JSON.stringify(editedUser));
          setIsEditing(false);
          alert("个人资料已成功更新");
        }
      } catch (error) {
        // 使用类型断言将error转换为AxiosError类型
        const err = error as AxiosError<any>;
        console.error("保存用户资料失败:", err);
        
        // 检查是否有响应
        if (err.response) {
          setError(`保存失败：${err.response.status} ${err.response.data?.detail || JSON.stringify(err.response.data) || '未知错误'}`);
        } else if (err.request) {
          setError("网络错误：无法连接到服务器，请检查网络连接");
        } else {
          setError(`请求错误：${err.message}`);
        }
      } finally {
        setIsLoading(false);
      }
    } else {
      setIsEditing(true);
    }
  };
  
  // 处理用户信息变更
  const handleUserDataChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setEditedUser(prev => ({
      ...prev,
      [name]: value
    }));
  };
  
  // 处理研究领域变更
  const handleResearchFieldsChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const fields: string[] = e.target.value.split(',').map(field => field.trim());
    setEditedUser(prev => ({
      ...prev,
      researchFields: fields
    }));
  };
  
  // 处理通知设置变更
  const handleNotificationChange = (settingName: keyof typeof notificationSettings) => {
    const updatedSettings = {
      ...notificationSettings,
      [settingName]: !notificationSettings[settingName]
    };
    setNotificationSettings(updatedSettings);
    localStorage.setItem("notificationSettings", JSON.stringify(updatedSettings));
  };
  
  // 处理隐私设置变更
  const handlePrivacyChange = (settingName: keyof typeof privacySettings) => {
    const updatedSettings = {
      ...privacySettings,
      [settingName]: !privacySettings[settingName]
    };
    setPrivacySettings(updatedSettings);
    localStorage.setItem("privacySettings", JSON.stringify(updatedSettings));
  };
  
  // 退出登录
  const handleLogout = () => {
    // 清除localStorage中的token
    localStorage.removeItem("token");
    localStorage.removeItem("userData");
    
    // 清除cookie中的token
    document.cookie = "token=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;";
    
    // 更新状态
    setIsLoggedIn(false);
    setUserData({
      id: 0,
      username: "访客用户",
      email: "example@example.com",
      avatar: null,
      researchFields: [],
      membershipType: "免费用户",
      expiryDate: "",
      credits: 0,
      registerDate: "-",
      institution: "",
      position: ""
    });
    
    // 可选：重定向到登录页面
    // window.location.href = '/login';
  };
  
  // 保存设置
  const handleSaveSettings = () => {
    localStorage.setItem("notificationSettings", JSON.stringify(notificationSettings));
    localStorage.setItem("privacySettings", JSON.stringify(privacySettings));
    alert("设置保存成功");
  };
  
  // 使用记录部分的渲染
  const renderHistoryContent = () => {
    return (
      <div>
        <h3 className="text-lg font-medium text-white mb-4">聊天历史</h3>
        {chatHistory.length === 0 ? (
          <p className="text-white/60">暂无聊天历史记录</p>
        ) : (
          <div className="space-y-3">
            {chatHistory.map((chat: any) => (
              <div key={chat.id} className="p-3 bg-white/5 rounded-lg hover:bg-white/10">
                <div className="flex justify-between items-center">
                  <h4 className="font-medium text-white">{chat.title}</h4>
                  <span className="text-white/50 text-sm">
                    {new Date(chat.created_at).toLocaleDateString()}
                  </span>
                </div>
                <Link href={`/ai-chat?id=${chat.id}`} className="mt-2 text-[var(--theme-accent)] text-sm hover:underline">
                  查看对话
                </Link>
              </div>
            ))}
          </div>
        )}
        
        <h3 className="text-lg font-medium text-white mb-4 mt-8">研究历史</h3>
        {researchHistory.length === 0 ? (
          <p className="text-white/60">暂无研究历史记录</p>
        ) : (
          <div className="space-y-3">
            {researchHistory.map((research: any) => (
              <div key={research.id} className="p-3 bg-white/5 rounded-lg hover:bg-white/10">
                <div className="flex justify-between items-center">
                  <h4 className="font-medium text-white">{research.title}</h4>
                  <span className="text-white/50 text-sm">
                    {new Date(research.created_at).toLocaleDateString()}
                  </span>
                </div>
                <Link href={`/research?id=${research.id}`} className="mt-2 text-[var(--theme-accent)] text-sm hover:underline">
                  查看研究
                </Link>
              </div>
            ))}
          </div>
        )}
      </div>
    );
  };
  
  // 添加处理登录的函数
  const handleLogin = async (e: React.FormEvent) => {
    e.preventDefault();
    setLoginError('');
    setIsLoading(true);
    
    try {
      console.log("开始登录流程...");
      
      // 创建FormData
      const formData = new FormData();
      formData.append('username', loginUsername);
      formData.append('password', loginPassword);
      
      // 登录请求
      console.log("发送登录请求到:", `${API_BASE_URL}/auth/token`);
      const response = await fetch(`${API_BASE_URL}/auth/token`, {
        method: 'POST',
        body: formData
      });
      
      // 检查响应状态
      console.log("登录请求状态:", response.status);
      if (!response.ok) {
        const errorText = await response.text();
        console.error("登录失败:", errorText);
        throw new Error('用户名或密码不正确');
      }
      
      const data = await response.json();
      console.log("登录成功，获取到token");
      
      // 保存token到localStorage和cookie
      localStorage.setItem('token', data.access_token);
      document.cookie = `token=${data.access_token}; path=/; max-age=86400`; // 设置为1天过期
      
      // 获取用户资料
      console.log("获取用户资料...");
      const userResponse = await fetch(`${API_BASE_URL}/users/profile`, {
        headers: {
          'Authorization': `Bearer ${data.access_token}`
        }
      });
      
      if (!userResponse.ok) {
        console.error("获取用户资料失败:", userResponse.status);
        throw new Error('登录成功但无法获取用户资料');
      }
      
      const userData = await userResponse.json();
      console.log("获取用户资料成功:", userData);
      
      // 确保researchFields是数组
      if (!userData.researchFields) {
        userData.researchFields = ["人工智能", "机器学习", "自然语言处理"];
      }
      
      localStorage.setItem('userData', JSON.stringify(userData));
      
      // 更新状态
      setUserData(userData);
      setEditedUser(userData);
      setIsLoggedIn(true);
      setIsLoading(false);
    } catch (err) {
      const error = err as any;
      console.error('登录过程出错:', error);
      
      if (error.response) {
        setLoginError(error.response.data?.detail || `错误(${error.response.status})`);
      } else if (error.message) {
        setLoginError(error.message);
      } else {
        setLoginError('登录失败，请稍后再试');
      }
      setIsLoading(false);
    }
  };
  
  return (
    <main className="relative flex min-h-[calc(100vh-64px)] flex-col">
      <div className="container mx-auto px-4 py-6 flex flex-col">
        <div className="text-center mb-6">
          <h1 className="text-4xl font-bold text-center text-transparent bg-clip-text bg-gradient-to-r from-white to-white/70 mb-2 drop-shadow-lg">
            个人中心
          </h1>
          <p className="text-white/80 mb-2">
            管理您的账户和研究项目
          </p>
          <div className="w-16 h-1 mx-auto bg-gradient-to-r from-[var(--theme-accent)] to-[var(--theme-highlight)] rounded-full"></div>
        </div>
        
        {error && (
          <div className="bg-red-500/20 p-3 mb-6 rounded-lg text-white">
            {error}
          </div>
        )}
        
        <div className="grid grid-cols-1 lg:grid-cols-4 gap-6">
          {/* 侧边导航 - 大屏幕上显示在左侧 */}
          <div className="lg:col-span-1">
            <GlassCard className="w-full overflow-hidden p-0">
              <div className="p-4 border-b border-white/10 text-center">
                <div className="w-20 h-20 bg-gradient-to-br from-[var(--theme-accent)] to-[var(--theme-highlight)] rounded-full mx-auto flex items-center justify-center text-white text-2xl font-bold">
                  {userData.username.substring(0, 1)}
                </div>
                <h3 className="text-white font-medium mt-3">{userData.username}</h3>
                <p className="text-white/60 text-sm">{userData.institution} · {userData.position}</p>
              </div>
              
              <nav className="p-2">
                {tabs.map((tab) => (
                  <button
                    key={tab.id}
                    className={`w-full flex items-center gap-3 px-4 py-3 rounded-lg text-left ${
                      activeTab === tab.id 
                        ? "bg-white/10 text-white" 
                        : "text-white/70 hover:bg-white/5 hover:text-white"
                    }`}
                    onClick={() => setActiveTab(tab.id)}
                  >
                    <span className="text-[var(--theme-accent)]">{tab.icon}</span>
                    <span>{tab.label}</span>
                    
                    {/* 活动指示器 */}
                    {activeTab === tab.id && (
                      <span className="ml-auto w-1.5 h-1.5 rounded-full bg-[var(--theme-accent)]"></span>
                    )}
                  </button>
                ))}
              </nav>
              
              <div className="p-4 border-t border-white/10 mt-2">
                <p className="text-white/50 text-xs text-center">
                  {userData.membershipType} · 到期时间: {userData.expiryDate}
                </p>
              </div>
            </GlassCard>
          </div>
          
          {/* 内容区域 */}
          <div className="lg:col-span-3">
            <GlassCard className="w-full overflow-hidden">
              {isLoading ? (
                <div className="text-center py-10">
                  <div className="inline-block w-6 h-6 border-2 border-t-[var(--theme-accent)] border-white/20 rounded-full animate-spin"></div>
                  <p className="mt-2 text-white/60">加载中...</p>
                </div>
              ) : !isLoggedIn ? (
                // 未登录状态显示登录表单
                <div className="p-6">
                  <h2 className="text-xl font-bold text-white mb-6">请登录您的账户</h2>
                  
                  {loginError && (
                    <div className="bg-red-500/20 p-3 mb-6 rounded-lg text-white">
                      {loginError}
                    </div>
                  )}
                  
                  <form onSubmit={handleLogin} className="space-y-6">
                    <div>
                      <label className="block text-white/60 text-sm mb-2">用户名</label>
                      <input 
                        type="text"
                        className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                        value={loginUsername}
                        onChange={(e) => setLoginUsername(e.target.value)}
                        required
                      />
                    </div>
                    
                    <div>
                      <label className="block text-white/60 text-sm mb-2">密码</label>
                      <input 
                        type="password"
                        className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                        value={loginPassword}
                        onChange={(e) => setLoginPassword(e.target.value)}
                        required
                      />
                    </div>
                    
                    <Button 
                      type="submit" 
                      className="w-full" 
                      disabled={isLoading}
                    >
                      {isLoading ? (
                        <div className="inline-block w-6 h-6 border-2 border-t-transparent border-white rounded-full animate-spin"></div>
                      ) : '登录'}
                    </Button>
                  </form>
                  
                  <div className="mt-6 text-center">
                    <p className="text-white/60">
                      还没有账户？ 
                      <Link href="/register" className="text-[var(--theme-accent)] hover:underline ml-1">
                        注册
                      </Link>
                    </p>
                  </div>
                </div>
              ) : (
                <>
                  {/* 个人信息标签页 */}
                  {activeTab === "profile" && (
                    <div className="space-y-6 p-6">
                      <div className="flex justify-between items-center">
                        <h2 className="text-xl font-bold text-white">个人信息</h2>
                        <Button 
                          onClick={toggleEditMode}
                          variant={isEditing ? "default" : "outline"}
                        >
                          {isEditing ? "保存" : "编辑资料"}
                        </Button>
                      </div>
                      
                      <div className="space-y-4">
                        <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                          <div>
                            <label className="block text-white/60 text-sm mb-1">用户名</label>
                            {isEditing ? (
                              <input 
                                type="text" 
                                name="username"
                                className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                                value={editedUser.username}
                                onChange={handleUserDataChange}
                              />
                            ) : (
                              <p className="bg-white/5 p-2 rounded-lg text-white">{userData.username}</p>
                            )}
                          </div>
                          
                          <div>
                            <label className="block text-white/60 text-sm mb-1">邮箱</label>
                            {isEditing ? (
                              <input 
                                type="email" 
                                name="email"
                                className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                                value={editedUser.email}
                                onChange={handleUserDataChange}
                              />
                            ) : (
                              <p className="bg-white/5 p-2 rounded-lg text-white">{userData.email}</p>
                            )}
                          </div>
                        </div>
                        
                        <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                          <div>
                            <label className="block text-white/60 text-sm mb-1">所属机构</label>
                            {isEditing ? (
                              <input 
                                type="text" 
                                name="institution"
                                className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                                value={editedUser.institution}
                                onChange={handleUserDataChange}
                              />
                            ) : (
                              <p className="bg-white/5 p-2 rounded-lg text-white">{userData.institution}</p>
                            )}
                          </div>
                          
                          <div>
                            <label className="block text-white/60 text-sm mb-1">职位</label>
                            {isEditing ? (
                              <input 
                                type="text" 
                                name="position"
                                className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                                value={editedUser.position}
                                onChange={handleUserDataChange}
                              />
                            ) : (
                              <p className="bg-white/5 p-2 rounded-lg text-white">{userData.position}</p>
                            )}
                          </div>
                        </div>
                        
                        <div>
                          <label className="block text-white/60 text-sm mb-1">研究领域</label>
                          {isEditing ? (
                            <input 
                              type="text" 
                              name="researchFields"
                              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-2 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                              value={editedUser.researchFields.join(', ')}
                              onChange={handleResearchFieldsChange}
                            />
                          ) : (
                            <div className="bg-white/5 p-2 rounded-lg text-white">
                              <div className="flex flex-wrap gap-2">
                                {(userData.researchFields || []).map((field, index) => (
                                  <span 
                                    key={index}
                                    className="px-2 py-1 rounded-full bg-[var(--theme-accent)]/20 text-white text-sm"
                                  >
                                    {field}
                                  </span>
                                ))}
                              </div>
                            </div>
                          )}
                        </div>
                      </div>
                      
                      {/* 账户信息卡片 */}
                      <div className="mt-6 p-4 bg-white/5 rounded-lg">
                        <h3 className="text-lg font-medium text-white mb-3">账户信息</h3>
                        <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                          <div>
                            <p className="text-white/60 text-sm">会员类型</p>
                            <p className="text-white font-medium">{userData.membershipType}</p>
                          </div>
                          <div>
                            <p className="text-white/60 text-sm">到期时间</p>
                            <p className="text-white font-medium">{userData.expiryDate}</p>
                          </div>
                          <div>
                            <p className="text-white/60 text-sm">可用积分</p>
                            <p className="text-white font-medium">{userData.credits.toLocaleString()}</p>
                          </div>
                          <div>
                            <p className="text-white/60 text-sm">注册时间</p>
                            <p className="text-white font-medium">{userData.registerDate}</p>
                          </div>
                        </div>
                        
                        <div className="mt-4 flex justify-end gap-3">
                          <Button variant="outline" size="sm">
                            升级会员
                          </Button>
                          <Button size="sm">
                            充值积分
                          </Button>
                        </div>
                      </div>
                    </div>
                  )}
                  
                  {/* 使用记录标签页 */}
                  {activeTab === "history" && (
                    <div 
                      className="p-6 max-h-[70vh] overflow-y-auto scroll-smooth" 
                      style={{ 
                        scrollbarWidth: 'thin',
                        scrollbarColor: 'rgba(255,255,255,0.2) transparent'
                      }}
                    >
                      <h2 className="text-xl font-bold text-white mb-6">使用记录</h2>
                      {isLoading ? (
                        <div className="text-center py-10">
                          <div className="inline-block w-6 h-6 border-2 border-t-[var(--theme-accent)] border-white/20 rounded-full animate-spin"></div>
                          <p className="mt-2 text-white/60">加载中...</p>
                        </div>
                      ) : (
                        renderHistoryContent()
                      )}
                    </div>
                  )}
                  
                  {/* 收藏论文标签页 */}
                  {activeTab === "favorites" && (
                    <div 
                      className="p-6 max-h-[70vh] overflow-y-auto scroll-smooth" 
                      style={{ 
                        scrollbarWidth: 'thin',
                        scrollbarColor: 'rgba(255,255,255,0.2) transparent'
                      }}
                    >
                      <h2 className="text-xl font-bold text-white mb-6">收藏论文</h2>
                      
                      <div className="flex justify-between items-center mb-4">
                        <div className="relative">
                          <input 
                            type="text" 
                            placeholder="搜索收藏..." 
                            className="bg-white/10 text-white border border-white/20 rounded-lg pl-8 pr-2 py-1 text-sm focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
                          />
                          <svg xmlns="http://www.w3.org/2000/svg" width="14" height="14" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="absolute left-2.5 top-2 text-white/60">
                            <circle cx="11" cy="11" r="8"></circle>
                            <path d="m21 21-4.3-4.3"></path>
                          </svg>
                        </div>
                      </div>
                      
                      <div className="space-y-4">
                        {/* 模拟收藏论文数据 */}
                        {/* 实际应用中应从数据库获取收藏论文数据 */}
                        {/* 这里使用本地数据作为示例 */}
                        {/* 实际应用中应从数据库获取收藏论文数据 */}
                        {/* 这里使用本地数据作为示例 */}
                      </div>
                      
                      <div className="mt-8 text-center">
                        <Link href="/">
                          <Button variant="default">
                            <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="mr-2">
                              <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path>
                              <polyline points="7 10 12 15 17 10"></polyline>
                              <line x1="12" x2="12" y1="15" y2="3"></line>
                            </svg>
                            浏览更多论文
                          </Button>
                        </Link>
                      </div>
                    </div>
                  )}
                  
                  {/* 系统设置标签页 */}
                  {activeTab === "settings" && (
                    <div 
                      className="p-6 max-h-[70vh] overflow-y-auto scroll-smooth" 
                      style={{ 
                        scrollbarWidth: 'thin',
                        scrollbarColor: 'rgba(255,255,255,0.2) transparent'
                      }}
                    >
                      <h2 className="text-xl font-bold text-white mb-6">系统设置</h2>
                      
                      {/* 主题设置 */}
                      <div>
                        <h3 className="text-lg font-medium text-white mb-3">外观与主题</h3>
                        <div className="bg-white/5 p-4 rounded-lg">
                          <div className="mb-4">
                            <label className="block text-white/60 text-sm mb-2">主题模式</label>
                            <div className="flex gap-3">
                              <label className="flex items-center">
                                <input 
                                  type="radio" 
                                  name="theme" 
                                  className="mr-2" 
                                  checked={isDarkMode} 
                                  onChange={() => setIsDarkMode(true)}
                                />
                                <span className="text-white">深色</span>
                              </label>
                              <label className="flex items-center">
                                <input 
                                  type="radio" 
                                  name="theme" 
                                  className="mr-2"
                                  checked={!isDarkMode}
                                  onChange={() => setIsDarkMode(false)}
                                />
                                <span className="text-white">浅色</span>
                              </label>
                            </div>
                          </div>
                          
                          <div>
                            <label className="block text-white/60 text-sm mb-2">主题颜色</label>
                            <div className="flex gap-3">
                              <button className="w-8 h-8 rounded-full bg-blue-500 border-2 border-white"></button>
                              <button className="w-8 h-8 rounded-full bg-purple-500"></button>
                              <button className="w-8 h-8 rounded-full bg-green-500"></button>
                              <button className="w-8 h-8 rounded-full bg-amber-500"></button>
                              <button className="w-8 h-8 rounded-full bg-rose-500"></button>
                            </div>
                          </div>
                        </div>
                      </div>
                      
                      {/* 通知设置 */}
                      <div>
                        <h3 className="text-lg font-medium text-white mb-3">通知设置</h3>
                        <div className="bg-white/5 p-4 rounded-lg space-y-3">
                          <div className="flex items-center justify-between">
                            <div>
                              <label className="text-white">电子邮件通知</label>
                              <p className="text-white/60 text-xs mt-1">接收系统重要通知和更新</p>
                            </div>
                            <label className="relative inline-flex items-center cursor-pointer">
                              <input 
                                type="checkbox" 
                                className="sr-only peer" 
                                checked={notificationSettings.email}
                                onChange={() => handleNotificationChange('email')}
                              />
                              <div className="w-11 h-6 bg-white/20 peer-focus:outline-none rounded-full peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all peer-checked:bg-[var(--theme-accent)]"></div>
                            </label>
                          </div>
                          
                          <div className="flex items-center justify-between">
                            <div>
                              <label className="text-white">新研究成果提醒</label>
                              <p className="text-white/60 text-xs mt-1">获取相关研究领域的最新动态</p>
                            </div>
                            <label className="relative inline-flex items-center cursor-pointer">
                              <input 
                                type="checkbox" 
                                className="sr-only peer" 
                                checked={notificationSettings.research}
                                onChange={() => handleNotificationChange('research')}
                              />
                              <div className="w-11 h-6 bg-white/20 peer-focus:outline-none rounded-full peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all peer-checked:bg-[var(--theme-accent)]"></div>
                            </label>
                          </div>
                          
                          <div className="flex items-center justify-between">
                            <div>
                              <label className="text-white">系统更新通知</label>
                              <p className="text-white/60 text-xs mt-1">了解新功能和系统改进</p>
                            </div>
                            <label className="relative inline-flex items-center cursor-pointer">
                              <input 
                                type="checkbox" 
                                className="sr-only peer" 
                                checked={notificationSettings.updates}
                                onChange={() => handleNotificationChange('updates')}
                              />
                              <div className="w-11 h-6 bg-white/20 peer-focus:outline-none rounded-full peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all peer-checked:bg-[var(--theme-accent)]"></div>
                            </label>
                          </div>
                        </div>
                      </div>
                      
                      {/* 隐私设置 */}
                      <div>
                        <h3 className="text-lg font-medium text-white mb-3">隐私与安全</h3>
                        <div className="bg-white/5 p-4 rounded-lg space-y-3">
                          <div className="flex items-center justify-between">
                            <div>
                              <label className="text-white">启用双因素认证</label>
                              <p className="text-white/60 text-xs mt-1">增强账户安全性</p>
                            </div>
                            <label className="relative inline-flex items-center cursor-pointer">
                              <input 
                                type="checkbox" 
                                className="sr-only peer" 
                                checked={privacySettings.twoFactor}
                                onChange={() => handlePrivacyChange('twoFactor')}
                              />
                              <div className="w-11 h-6 bg-white/20 peer-focus:outline-none rounded-full peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all peer-checked:bg-[var(--theme-accent)]"></div>
                            </label>
                          </div>
                          
                          <div className="flex items-center justify-between">
                            <div>
                              <label className="text-white">允许数据分析以改进服务</label>
                              <p className="text-white/60 text-xs mt-1">帮助我们提升使用体验</p>
                            </div>
                            <label className="relative inline-flex items-center cursor-pointer">
                              <input 
                                type="checkbox" 
                                className="sr-only peer" 
                                checked={privacySettings.dataAnalysis}
                                onChange={() => handlePrivacyChange('dataAnalysis')}
                              />
                              <div className="w-11 h-6 bg-white/20 peer-focus:outline-none rounded-full peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all peer-checked:bg-[var(--theme-accent)]"></div>
                            </label>
                          </div>
                          
                          <div className="mt-4">
                            <Button variant="outline" className="text-sm">修改密码</Button>
                          </div>
                        </div>
                      </div>
                      
                      <div className="flex justify-between mt-6">
                        <Button 
                          variant="ghost" 
                          className="text-red-400 hover:text-red-300 hover:bg-red-500/20"
                          onClick={handleLogout}
                        >
                          <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="mr-2">
                            <path d="M10 16l-6-6 6-6"></path>
                            <path d="M20 21v-7a4 4 0 0 0-4-4H5"></path>
                          </svg>
                          退出登录
                        </Button>
                        <Button onClick={handleSaveSettings}>
                          保存设置
                        </Button>
                      </div>
                    </div>
                  )}
                </>
              )}
            </GlassCard>
          </div>
        </div>
      </div>
    </main>
  );
}