"use client";

import { useState, useEffect } from 'react';
import { GlassCard } from "@/components/ui/glass-card";
import { Button } from "@/components/ui/button";
import axios from 'axios';
import { useRouter } from 'next/navigation';
import Link from 'next/link';

// API基础URL
const API_BASE_URL = process.env.NEXT_PUBLIC_API_URL || "http://localhost:8000/api";

// 在文件顶部添加类型定义
interface ApiError {
  message: string;
  response?: {
    status: number;
    data: any;
  };
}

interface ApiErrorResponse {
  detail?: string;
  status?: number;
  [key: string]: any;
}

type FetchError = Error & {
  response?: {
    status: number;
    data: ApiErrorResponse;
  };
}

export default function RegisterPage() {
  const [username, setUsername] = useState('');
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [confirmPassword, setConfirmPassword] = useState('');
  const [institution, setInstitution] = useState('江西财经大学');
  const [position, setPosition] = useState('学生');
  const [error, setError] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const router = useRouter();
  
  // 添加测试函数
  const testBackendConnection = async () => {
    try {
      console.log("尝试连接到后端健康检查端点...");
      const response = await fetch("http://localhost:8000/health", {
        method: "GET",
      });
      const data = await response.text();
      console.log("后端连接测试成功:", data);
      return true;
    } catch (error) {
      console.error("后端连接测试失败:", error);
      return false;
    }
  };

  // 在组件挂载时测试连接
  useEffect(() => {
    testBackendConnection();
  }, []);
  
  const handleRegister = async (e: React.FormEvent) => {
    e.preventDefault();
    setError('');
    
    // 验证密码匹配
    if (password !== confirmPassword) {
      setError('两次输入的密码不匹配');
      return;
    }
    
    setIsLoading(true);
    
    const registerData = {
      username,
      email,
      password,
      institution,
      position
    };
    
    try {
      console.log("注册请求开始...");
      
      // 使用fetch API
      const response = await fetch(`${API_BASE_URL}/auth/register`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(registerData)
      });
      
      const responseText = await response.text();
      console.log("注册响应状态:", response.status);
      
      if (!response.ok) {
        // 尝试解析错误JSON
        let errorDetail: string;
        try {
          const errorData = JSON.parse(responseText);
          errorDetail = errorData.detail || `注册失败: ${response.status}`;
        } catch {
          // 如果无法解析JSON，使用原始文本
          errorDetail = responseText || `注册失败: ${response.status}`;
        }
        
        throw new Error(errorDetail);
      }
      
      // 解析成功响应
      const data = JSON.parse(responseText);
      console.log("注册成功:", data);
      
      // 自动登录
      const formData = new FormData();
      formData.append('username', username);
      formData.append('password', password);
      
      const loginResponse = await fetch(`${API_BASE_URL}/auth/token`, {
        method: 'POST',
        body: formData
      });
      
      if (!loginResponse.ok) {
        throw new Error('注册成功但登录失败，请尝试直接登录');
      }
      
      const loginData = await loginResponse.json();
      localStorage.setItem('token', loginData.access_token);
      
      // 获取用户资料
      const userResponse = await fetch(`${API_BASE_URL}/users/profile`, {
        headers: {
          'Authorization': `Bearer ${loginData.access_token}`
        }
      });
      
      if (!userResponse.ok) {
        throw new Error('获取用户资料失败');
      }
      
      const userData = await userResponse.json();
      localStorage.setItem('userData', JSON.stringify(userData));
      
      // 跳转到首页
      window.location.href = '/dashboard';
    } catch (err) {
      console.error('注册过程出错:', err);
      
      // 处理不同类型的错误
      const errorMessage = err instanceof Error 
        ? err.message 
        : '注册失败，请稍后再试';
      
      // 友好的错误提示
      if (errorMessage.includes('用户名已被使用')) {
        setError('该用户名已被注册，请尝试其他用户名');
      } else if (errorMessage.includes('邮箱已被使用')) {
        setError('该邮箱已被注册，请使用其他邮箱');
      } else {
        setError(errorMessage);
      }
    } finally {
      setIsLoading(false);
    }
  };
  
  return (
    <main className="flex items-center justify-center min-h-screen p-4">
      <GlassCard className="w-full max-w-md">
        <h1 className="text-3xl font-bold text-center text-white mb-8">注册</h1>
        
        {error && (
          <div className="bg-red-500/20 p-3 mb-6 rounded-lg text-white">
            {error}
          </div>
        )}
        
        <form onSubmit={handleRegister} className="space-y-4">
          <div>
            <label className="block text-white/60 text-sm mb-2">用户名</label>
            <input 
              type="text"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={username}
              onChange={(e) => setUsername(e.target.value)}
              required
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">邮箱</label>
            <input 
              type="email"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              required
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">密码</label>
            <input 
              type="password"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              required
              minLength={6}
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">确认密码</label>
            <input 
              type="password"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={confirmPassword}
              onChange={(e) => setConfirmPassword(e.target.value)}
              required
              minLength={6}
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">所属机构</label>
            <input 
              type="text"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={institution}
              onChange={(e) => setInstitution(e.target.value)}
            />
          </div>
          
          <div>
            <label className="block text-white/60 text-sm mb-2">职位</label>
            <input 
              type="text"
              className="w-full bg-white/10 text-white border border-white/20 rounded-lg p-3 focus:outline-none focus:ring-2 focus:ring-[var(--theme-accent)]/50"
              value={position}
              onChange={(e) => setPosition(e.target.value)}
            />
          </div>
          
          <Button 
            type="submit" 
            className="w-full mt-6" 
            disabled={isLoading}
          >
            {isLoading ? (
              <div className="inline-block w-6 h-6 border-2 border-t-transparent border-white rounded-full animate-spin"></div>
            ) : '注册'}
          </Button>
        </form>
        
        <div className="mt-6 text-center">
          <p className="text-white/60">
            已有账号？ 
            <Link href="/login" className="text-[var(--theme-accent)] hover:underline ml-1">
              登录
            </Link>
          </p>
        </div>
      </GlassCard>
    </main>
  );
} 