import { useState } from "react";
import { motion } from "framer-motion";

interface Paper {
  id: string;
  title: string;
  authors: string[];
  summary: string;
  published: string;
  link: string;
  source: string;
  cluster?: number;  // 新增：论文所属聚类
}

interface Cluster {
  id: number;
  name: string;
  keywords: string[];
}

interface PaperListProps {
  papers: Paper[];
  clusters?: Cluster[];  // 新增：聚类信息
  onViewReport: () => void;
}

export function PaperList({ papers, clusters, onViewReport }: PaperListProps) {
  const [expandedPaper, setExpandedPaper] = useState<string | null>(null);
  
  if (!papers || papers.length === 0) {
    return (
      <div className="text-center py-8 text-white/70">
        未找到相关论文
      </div>
    );
  }
  
  const toggleExpand = (id: string) => {
    setExpandedPaper(expandedPaper === id ? null : id);
  };
  
  return (
    <div className="space-y-4">
      <div className="flex justify-between items-center">
        <h3 className="text-md font-medium text-white/90">找到 {papers.length} 篇相关论文</h3>
        <button
          onClick={onViewReport}
          className="px-3 py-1 bg-white/10 hover:bg-white/20 rounded text-white/80 text-sm"
        >
          查看研究报告
        </button>
      </div>
      
      {/* 如果有聚类信息，按聚类展示论文 */}
      {clusters && clusters.length > 0 ? (
        <div className="space-y-6">
          {clusters.map((cluster) => (
            <div key={cluster.id} className="space-y-3">
              <div className="border-l-2 border-[var(--theme-accent)] pl-3">
                <h4 className="text-white/90 font-medium">{cluster.name}</h4>
                
                {cluster.keywords && cluster.keywords.length > 0 && (
                  <div className="flex flex-wrap gap-1 mt-1">
                    {cluster.keywords.map((keyword, idx) => (
                      <span 
                        key={idx} 
                        className="text-xs px-2 py-0.5 rounded-full bg-white/10 text-white/60"
                      >
                        {keyword}
                      </span>
                    ))}
                  </div>
                )}
              </div>
              
              <div className="space-y-4 pl-2">
                {papers
                  .filter(paper => paper.cluster === cluster.id)
                  .map((paper) => (
                    <PaperCard 
                      key={paper.id} 
                      paper={paper} 
                      expanded={expandedPaper === paper.id}
                      toggleExpand={() => toggleExpand(paper.id)}
                    />
                  ))
                }
              </div>
            </div>
          ))}
        </div>
      ) : (
        <div className="space-y-4">
          {/* 如果没有聚类信息，按普通列表展示 */}
          {papers.map((paper) => (
            <PaperCard 
              key={paper.id} 
              paper={paper} 
              expanded={expandedPaper === paper.id}
              toggleExpand={() => toggleExpand(paper.id)}
            />
          ))}
        </div>
      )}
    </div>
  );
}

// 提取论文卡片为独立组件
function PaperCard({ paper, expanded, toggleExpand }) {
  return (
    <motion.div
      initial={{ opacity: 0 }}
      animate={{ opacity: 1 }}
      className="p-4 rounded-lg bg-white/10 border border-white/20"
    >
      <div className="flex justify-between">
        <h4 className="text-white/90 font-medium">{paper.title}</h4>
        <button
          onClick={toggleExpand}
          className="ml-2 flex-shrink-0 text-white/60 hover:text-white"
        >
          {expanded ? "收起" : "展开"}
        </button>
      </div>
      
      <p className="text-white/70 text-sm mt-1">
        {paper.authors.join(", ")}
      </p>
      
      <p className="text-white/50 text-xs mt-1">
        发布于: {new Date(paper.published).toLocaleDateString()}
      </p>
      
      {expanded && (
        <motion.div
          initial={{ height: 0, opacity: 0 }}
          animate={{ height: "auto", opacity: 1 }}
          className="mt-3 space-y-3"
        >
          <p className="text-white/80 text-sm">
            {paper.summary}
          </p>
          
          <div className="flex gap-2">
            <a
              href={paper.link}
              target="_blank"
              rel="noopener noreferrer"
              className="px-3 py-1 bg-[var(--theme-accent)] hover:bg-[var(--theme-accent)]/80 rounded text-white text-sm"
            >
              阅读论文
            </a>
            <a
              href={`https://arxiv.org/pdf/${paper.id}.pdf`}
              target="_blank"
              rel="noopener noreferrer"
              className="px-3 py-1 bg-white/20 hover:bg-white/30 rounded text-white text-sm"
            >
              下载PDF
            </a>
          </div>
        </motion.div>
      )}
    </motion.div>
  );
} 