import { useState } from "react";

interface ReportPanelProps {
  report: string;
  direction: string;
}

export function ReportPanel({ report, direction }: ReportPanelProps) {
  const [isExporting, setIsExporting] = useState(false);
  
  const handleExport = () => {
    setIsExporting(true);
    
    try {
      // Create a Blob with the report content
      const blob = new Blob([
        `# 研究报告: ${direction}\n\n${report}`
      ], { type: 'text/markdown' });
      
      // Create a URL for the Blob
      const url = URL.createObjectURL(blob);
      
      // Create a download link and trigger it
      const a = document.createElement('a');
      a.href = url;
      a.download = `research-report-${Date.now()}.md`;
      document.body.appendChild(a);
      a.click();
      
      // Clean up
      document.body.removeChild(a);
      URL.revokeObjectURL(url);
    } catch (error) {
      console.error('Export error:', error);
    } finally {
      setIsExporting(false);
    }
  };
  
  // Format the report text with Markdown-like styling
  const formatReport = () => {
    return report.split('\n').map((line, index) => {
      if (line.startsWith('# ')) {
        return <h1 key={index} className="text-xl font-bold mt-6 mb-3">{line.slice(2)}</h1>;
      } else if (line.startsWith('## ')) {
        return <h2 key={index} className="text-lg font-bold mt-5 mb-2">{line.slice(3)}</h2>;
      } else if (line.startsWith('### ')) {
        return <h3 key={index} className="text-md font-bold mt-4 mb-2">{line.slice(4)}</h3>;
      } else if (line.trim() === '') {
        return <div key={index} className="my-2"></div>;
      } else {
        return <p key={index} className="my-2 text-white/80">{line}</p>;
      }
    });
  };
  
  return (
    <div className="space-y-4">
      <div className="flex justify-between items-center">
        <h3 className="text-lg font-medium text-white/90">{direction}</h3>
        <button
          onClick={handleExport}
          disabled={isExporting}
          className="px-3 py-1 bg-[var(--theme-accent)] hover:bg-[var(--theme-accent)]/80 rounded text-white text-sm disabled:opacity-50"
        >
          {isExporting ? "导出中..." : "导出报告"}
        </button>
      </div>
      
      <div className="p-4 rounded-lg bg-white/10 border border-white/20 max-h-[600px] overflow-y-auto">
        <div className="prose prose-invert prose-sm max-w-none">
          {formatReport()}
        </div>
      </div>
    </div>
  );
} 