import { useState } from "react";
import { motion } from "framer-motion";

interface ResearchDirectionCardProps {
  direction: string;
  translation?: string;
  description?: string;
  keywords?: string[];
  isEnglish: boolean;
  isProcessing?: boolean;
  hasResults?: boolean;
  onClick: () => void;
}

export function ResearchDirectionCard({ 
  direction, 
  translation, 
  description,
  keywords,
  isEnglish, 
  isProcessing,
  hasResults,
  onClick 
}: ResearchDirectionCardProps) {
  const [showTranslation, setShowTranslation] = useState(false);
  
  // If English is the original language, we don't need to toggle translations
  const displayText = isEnglish 
    ? direction 
    : (showTranslation ? direction : translation || direction);
  
  const toggleTranslation = (e: React.MouseEvent) => {
    if (!isEnglish && translation) {
      e.stopPropagation();
      setShowTranslation(!showTranslation);
    }
  };
  
  return (
    <motion.div
      whileHover={{ scale: 1.01 }}
      className="p-4 rounded-lg bg-white/10 hover:bg-white/15 border border-white/20 cursor-pointer transition-colors"
      onClick={onClick}
    >
      <div className="flex justify-between items-start">
        <p className="text-white/90 text-md font-medium">{displayText}</p>
        
        {!isEnglish && translation && (
          <button 
            className="ml-2 px-2 py-1 text-xs bg-white/20 hover:bg-white/30 rounded text-white/70 flex-shrink-0"
            onClick={toggleTranslation}
          >
            {showTranslation ? "查看翻译" : "查看英文"}
          </button>
        )}
      </div>
      
      {description && (
        <p className="text-sm text-white/70 mt-2">{description}</p>
      )}
      
      {keywords && keywords.length > 0 && (
        <div className="flex flex-wrap gap-1 mt-2">
          {keywords.map((keyword, idx) => (
            <span 
              key={idx} 
              className="text-xs px-2 py-0.5 rounded-full bg-white/10 text-white/60"
            >
              {keyword}
            </span>
          ))}
        </div>
      )}
      
      <div className="flex items-center justify-between mt-3">
        <span className="text-xs text-white/50">
          {isProcessing ? "正在处理..." : hasResults ? "已完成分析" : "待处理"}
        </span>
        
        {isProcessing && (
          <div className="w-4 h-4 rounded-full border-2 border-transparent border-t-white/80 animate-spin"></div>
        )}
        
        {hasResults && (
          <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4 text-green-400" viewBox="0 0 20 20" fill="currentColor">
            <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
          </svg>
        )}
      </div>
    </motion.div>
  );
} 