"use client";

import { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { motion } from "framer-motion";
import { KeywordChip } from "@/components/ui/keyword-chip";
import { ResearchDirectionCard } from "@/components/ui/research-direction-card";
import { PaperList } from "@/components/ui/paper-list";
import { ReportPanel } from "@/components/ui/report-panel";
import { ErrorMessage } from "@/components/ui/error-message";

// 研究标题简化函数
const simplifyResearchTitle = (text) => {
  if (!text) return '';
  
  // 先提取引号中的内容作为最佳选项
  const quoteMatch = text.match(/["""](.*?)["""]/);
  if (quoteMatch && quoteMatch[1].length > 5) {
    return quoteMatch[1].trim();
  }
  
  // 提取标题的前半部分（通常是冒号前的内容）
  const colonParts = text.split(/[：:]/);
  if (colonParts.length > 1 && colonParts[0].length > 5) {
    // 只取冒号前的内容
    let mainTitle = colonParts[0].trim();
    // 再次清理序号和括号
    mainTitle = mainTitle.replace(/^\d+\.\s*/, '')
                         .replace(/\([^)]*\)/g, '')
                         .replace(/（[^）]*）/g, '')
                         .replace(/\s*注[:：].*$/, '');
    return mainTitle;
  }
  
  // 直接清理所有注释和说明
  let cleaned = text
    .replace(/^\d+\.\s*/, '')             // 移除序号
    .replace(/\([^)]*\)/g, '')           // 移除所有英文括号内容
    .replace(/（[^）]*）/g, '')           // 移除所有中文括号内容
    .replace(/[（\(]注[:：].*?[）\)]/g, '') // 移除带注释的括号内容
    .replace(/注[:：].*?(。|$)/g, '')      // 移除"注:"到句号或结尾的内容
    .replace(/\s+/g, ' ')                // 将多个空格合并为一个
    .trim();
  
  // 如果还是太长，截断
  if (cleaned.length > 40) {
    cleaned = cleaned.substring(0, 40) + '...';
  }
  
  return cleaned || text.substring(0, 40); // 如果清理后为空，使用原文前40个字符
};

export function ResearchForm({ onSubmit, className = "", onExport }: { onSubmit?: (data: any) => void, className?: string, onExport?: (data: any) => void }) {
  const [loading, setLoading] = useState(false);
  const [researchTopic, setResearchTopic] = useState("");
  const [researchData, setResearchData] = useState<any>(null);
  const [activeTab, setActiveTab] = useState("keywords");
  const [selectedDirection, setSelectedDirection] = useState<string | null>(null);
  const [error, setError] = useState<string | null>(null);
  const [progress, setProgress] = useState(1);
  const [processingDirections, setProcessingDirections] = useState(false);
  const [processingState, setProcessingState] = useState<string>("idle");
  const [processMessage, setProcessMessage] = useState<string>("");
  const [keywordsData, setKeywordsData] = useState<any>(null);
  const [directionsData, setDirectionsData] = useState<any>(null);
  const [papersData, setPapersData] = useState<any[]>([]);
  const [reportsData, setReportsData] = useState<any[]>([]);
  const [processingDirectionIndex, setProcessingDirectionIndex] = useState<number>(-1);
  const [searchKeywordsData, setSearchKeywordsData] = useState<any>(null);
  
  // 创建状态来跟踪研究阶段
  const [researchStage, setResearchStage] = useState("idle"); // idle, keywords, topics, searching, reporting, complete
  
  // 添加语言显示状态
  const [showEnglishKeywords, setShowEnglishKeywords] = useState(false);
  
  // 添加模态框状态
  const [modalOpen, setModalOpen] = useState(false);
  const [modalContent, setModalContent] = useState<{
    type: 'papers' | 'report',
    topicIndex: number,
    title: string
  } | null>(null);
  
  // 添加论文外部链接处理状态
  const [loadingPaperLink, setLoadingPaperLink] = useState(null);
  
  const API_URL = "http://localhost:8000";

  // 进度计算函数
  const calculateTaskBasedProgress = () => {
    // 基于研究阶段和处理状态计算进度
    // 总共定义了12个任务点，每个点完成后增加相应百分比
    
    let progressValue = 1; // 最小进度为1%
    
    switch (researchStage) {
      case 'idle':
        progressValue = 1;
        break;
      
      case 'keywords':
        // 关键词提取占15%的进度
        if (keywordsData) {
          progressValue = 15;
        } else {
          progressValue = 5;
        }
        break;
      
      case 'topics':
        // 关键词已完成(15%) + 研究方向生成进度(15%)
        if (directionsData && directionsData.research_topics) {
          progressValue = 30;
        } else {
          progressValue = 20;
        }
        break;
      
      case 'searching':
        // 关键词(15%) + 研究方向(15%) + 论文搜索进度(40%)
        const completedPapers = papersData.filter(p => p && p.papers).length;
        const topicsCount = directionsData?.research_topics?.length || 1;
        
        // 基础进度30% + 根据已完成的方向比例计算的进度(最多40%)
        progressValue = 30 + Math.floor((completedPapers / topicsCount) * 40);
        break;
      
      case 'reporting':
        // 关键词(15%) + 研究方向(15%) + 论文搜索(40%) + 报告生成进度(30%)
        const completedReports = reportsData.filter(r => r && r.report).length;
        const totalDirections = directionsData?.research_topics?.length || 1;
        
        // 基础进度70% + 根据已完成的报告比例计算的进度(最多25%)
        progressValue = 70 + Math.floor((completedReports / totalDirections) * 25);
        break;
      
      case 'complete':
        progressValue = 100;
        break;
    }
    
    return progressValue;
  };

  // 辅助函数用于决定步骤状态
  const getStepStatus = (stepIndex: number) => {
    const stages = ['keywords', 'topics', 'searching', 'reporting'];
    const currentStageIndex = stages.indexOf(researchStage);
    
    if (currentStageIndex > stepIndex || researchStage === 'complete') {
      return 'bg-green-500'; // 已完成
    } else if (currentStageIndex === stepIndex) {
      return 'bg-blue-500 animate-pulse'; // 进行中
    } else {
      return 'bg-gray-700 text-white/50'; // 未开始
    }
  };

  const isStepComplete = (stepIndex: number) => {
    const stages = ['keywords', 'topics', 'searching', 'reporting'];
    const currentStageIndex = stages.indexOf(researchStage);
    return currentStageIndex > stepIndex || researchStage === 'complete';
  };

  // 处理查看报告
  const handleViewReport = (topicIndex: number, e: React.MouseEvent) => {
    e.preventDefault();
    setModalContent({
      type: 'report',
      topicIndex,
      title: directionsData?.research_topics[topicIndex]?.title || `研究方向 ${topicIndex + 1}`
    });
    setModalOpen(true);
  };

  // 处理查看全部论文
  const handleViewAllPapers = (topicIndex: number, e: React.MouseEvent) => {
    e.preventDefault();
    setModalContent({
      type: 'papers',
      topicIndex,
      title: directionsData?.research_topics[topicIndex]?.title || `研究方向 ${topicIndex + 1}`
    });
    setModalOpen(true);
  };

  // 研究进度进度条组件
  const ResearchProgressBar = () => {
    // 研究阶段和对应的友好显示名称
    const stages = [
      { id: 'keywords', name: '关键词' },
      { id: 'topics', name: '研究方向' },
      { id: 'searching', name: '论文检索' },
      { id: 'reporting', name: '生成报告' }
    ];

    return (
      <div className="mb-6 bg-white/5 p-4 rounded-lg">
        <div className="text-sm text-white/80 mb-2">
          正在生成研究方向...
        </div>
        
        {/* 进度条 */}
        <div className="w-full bg-gray-700 h-2 rounded-full overflow-hidden mb-4">
          <div 
            className="h-full bg-blue-500 transition-all duration-500"
            style={{ 
              width: `${researchStage === 'complete' ? '100%' : 
                      researchStage === 'reporting' ? '75%' : 
                      researchStage === 'searching' ? '50%' : 
                      researchStage === 'topics' ? '25%' : 
                      researchStage === 'keywords' ? '12.5%' : '5%'}`
            }}
          ></div>
        </div>
        
        {/* 步骤指示器 */}
        <div className="flex justify-between">
          {stages.map((stage, index) => {
            // 确定步骤状态
            const currentStageIndex = stages.findIndex(s => s.id === researchStage);
            let statusClass = '';
            
            if (currentStageIndex > index || researchStage === 'complete') {
              statusClass = 'bg-green-500'; // 已完成
            } else if (currentStageIndex === index) {
              statusClass = 'bg-blue-500 animate-pulse'; // 进行中
            } else {
              statusClass = 'bg-gray-700'; // 未开始
            }
            
            return (
              <div key={stage.id} className="flex flex-col items-center">
                <div className={`w-6 h-6 rounded-full flex items-center justify-center ${statusClass}`}>
                  {currentStageIndex > index || researchStage === 'complete' ? (
                    <svg className="w-3 h-3 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                    </svg>
                  ) : (
                    <span className="text-xs text-white">{index + 1}</span>
                  )}
                </div>
                <span className={`text-xs mt-1 ${currentStageIndex === index ? 'text-white font-medium' : 'text-white/60'}`}>
                  {stage.name}
                </span>
              </div>
            );
          })}
        </div>
      </div>
    );
  };

  // 研究进展详细展示组件
  const ResearchProgressDisplay = () => {
    return (
      <div className="space-y-8">
        {/* 研究进度步骤 */}
        <div className="space-y-4">
          {/* 步骤1: 关键词提取 */}
          {keywordsData && (
            <div className="border-l-4 border-green-500 pl-4 bg-white/5 p-4 rounded-r-lg">
              <h4 className="text-sm font-medium text-white/90 mb-2 flex items-center">
                <svg className="w-4 h-4 mr-2 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                </svg>
                步骤1: 关键词提取完成
              </h4>
              
              <div className="flex flex-wrap gap-1.5">
                {(showEnglishKeywords 
                  ? (keywordsData?.keywords || []).slice(0, 8)
                  : (keywordsData?.translations || keywordsData?.keywords || []).slice(0, 8)
                ).map((keyword, idx) => (
                  <span 
                    key={idx} 
                    className="px-2 py-0.5 text-xs rounded-full bg-blue-500/20 text-blue-300"
                  >
                    {keyword}
                  </span>
                ))}
              </div>
              
              <button 
                onClick={() => setShowEnglishKeywords(!showEnglishKeywords)}
                className="text-xs text-blue-400 hover:text-blue-300 mt-2 flex items-center"
              >
                {showEnglishKeywords ? "查看中文关键词" : "查看英文关键词"}
              </button>
            </div>
          )}
          
          {/* 步骤2: 研究方向生成 */}
          {directionsData && directionsData.research_topics?.length > 0 && (
            <div className="border-l-4 border-indigo-500 pl-4 bg-white/5 p-4 rounded-r-lg">
              <h4 className="text-sm font-medium text-white/90 mb-2 flex items-center">
                <svg className="w-4 h-4 mr-2 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                </svg>
                步骤2: 研究方向生成完成
              </h4>
              
              <div className="space-y-2 mt-3">
                {directionsData.research_topics.map((topic, topicIdx) => (
                  <div 
                    key={topicIdx} 
                    className={`p-3 rounded ${
                      processingDirectionIndex === topicIdx 
                        ? 'bg-indigo-500/20 border border-indigo-500/40' 
                        : 'bg-white/10'
                    }`}
                  >
                    <h5 className="font-medium text-sm text-white/90">
                      {topicIdx + 1}. {topic.title || topic.english_title}
                    </h5>
                    
                    {/* 处理状态指示器 */}
                    {processingDirectionIndex === topicIdx && (
                      <div className="text-xs text-white/60 mt-1 flex items-center">
                        <div className="w-2 h-2 rounded-full bg-indigo-500 animate-pulse mr-2"></div>
                        {processingState === "searching_papers" && "正在搜索相关论文..."}
                        {processingState === "generating_report" && "正在生成研究报告..."}
                      </div>
                    )}
                  </div>
                ))}
              </div>
            </div>
          )}
          
          {/* 步骤3: 论文检索结果 */}
          {papersData.some(data => data && data.papers?.length > 0) && (
            <div className="border-l-4 border-blue-500 pl-4 bg-white/5 p-4 rounded-r-lg">
              <h4 className="text-sm font-medium text-white mb-2 flex items-center">
                <svg className="w-4 h-4 mr-2 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                </svg>
                步骤3: 论文检索完成
              </h4>
              
              <div className="grid gap-3 mt-3">
                {directionsData?.research_topics?.map((topic, idx) => (
                  // 只显示有论文的研究方向
                  papersData[idx] && papersData[idx].papers?.length > 0 ?
                    <div key={idx} className="border border-white/10 rounded-lg overflow-hidden">
                      <div className="bg-white/10 p-3">
                        <h5 className="font-medium text-sm text-white/90 flex justify-between">
                          <span>{topic.title || topic.english_title}</span>
                          <span className="text-green-400 text-xs flex items-center">
                            {papersData[idx].papers.length} 篇相关论文
                          </span>
                        </h5>
                      </div>
                      
                      <div className="p-3">
                        {/* 论文列表预览 */}
                        <div className="space-y-2 mb-2">
                          {papersData[idx].papers.slice(0, 2).map((paper, paperIdx) => (
                            <div key={paperIdx} className="text-xs text-white/80 truncate">
                              {paperIdx + 1}. {paper.title}
                            </div>
                          ))}
                          {papersData[idx].papers.length > 2 && (
                            <div className="text-xs text-white/50 italic">
                              ...以及更多 {papersData[idx].papers.length - 2} 篇论文
                            </div>
                          )}
                        </div>
                        
                        {/* 查看全部按钮 */}
                        <button 
                          onClick={(e) => handleViewAllPapers(idx, e)}
                          className="text-xs text-blue-400 hover:text-blue-300 flex items-center"
                        >
                          <span>查看全部论文</span>
                          <svg className="w-3 h-3 ml-1" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
                          </svg>
                        </button>
                      </div>
                    </div>
                  : null
                ))}
              </div>
            </div>
          )}
          
          {/* 步骤4: 研究报告生成 */}
          {reportsData.some(data => data && data.report) && (
            <div className="border-l-4 border-green-500 pl-4 bg-white/5 p-4 rounded-r-lg">
              <h4 className="text-sm font-medium text-white mb-2 flex items-center">
                <svg className="w-4 h-4 mr-2 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                </svg>
                步骤4: 研究报告生成
              </h4>
              
              <div className="space-y-4 mt-3 text-white">
                {directionsData?.research_topics?.map((topic, topicIdx) => (
                  // 仅显示已有报告的研究方向
                  reportsData[topicIdx] && reportsData[topicIdx].report ?
                    <div key={topicIdx} className="border border-white/10 rounded-lg overflow-hidden">
                      {/* 研究方向标题 */}
                      <div className="bg-white/10 p-3">
                        <h5 className="font-medium text-sm flex items-center">
                          <svg className="w-4 h-4 mr-2 text-green-500" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
                          </svg>
                          {topic.title || topic.english_title}
                        </h5>
                      </div>
                      
                      <div className="p-3">
                        <p className="text-xs text-white/70 line-clamp-2">
                          {reportsData[topicIdx].report.content?.substring(0, 150) || 
                          reportsData[topicIdx].report.english_content?.substring(0, 150)}...
                        </p>
                        
                        <button 
                          onClick={(e) => handleViewReport(topicIdx, e)}
                          className="text-xs text-blue-400 hover:text-blue-300 mt-2 flex items-center"
                        >
                          <span>查看完整研究报告</span>
                          <svg className="w-3 h-3 ml-1" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 5l7 7-7 7" />
                          </svg>
                        </button>
                      </div>
                    </div>
                  : null
                ))}
              </div>
            </div>
          )}
        </div>
      </div>
    );
  };

  // 模态框组件
  const PapersModal = () => {
    if (!modalOpen || !modalContent) return null;
    
    return (
      <div className="fixed inset-0 bg-black/70 flex items-center justify-center p-4 z-50">
        <div className="bg-gray-900 rounded-lg w-full max-w-3xl max-h-[80vh] overflow-hidden flex flex-col">
          <div className="p-4 border-b border-white/10 flex justify-between items-center">
            <h3 className="text-white font-medium">{modalContent.title}</h3>
            <button 
              onClick={() => setModalOpen(false)}
              className="text-white/60 hover:text-white"
            >
              ✕
            </button>
          </div>
          
          <div className="p-4 overflow-y-auto">
            {modalContent.type === 'papers' && papersData[modalContent.topicIndex]?.papers && (
              <PaperList papers={papersData[modalContent.topicIndex].papers} />
            )}
            
            {modalContent.type === 'report' && reportsData[modalContent.topicIndex]?.report && (
              <ReportPanel 
                report={reportsData[modalContent.topicIndex].report.content || reportsData[modalContent.topicIndex].report.english_content}
                direction={directionsData?.research_topics[modalContent.topicIndex]?.title || `研究方向 ${modalContent.topicIndex + 1}`}
              />
            )}
          </div>
        </div>
      </div>
    );
  };

  // 重置表单
  const resetForm = () => {
    setResearchTopic("");
    setResearchData(null);
    setSelectedDirection(null);
    setKeywordsData(null);
    setDirectionsData(null);
    setPapersData([]);
    setReportsData([]);
    setProcessingState("idle");
    setProcessMessage("");
    setError(null);
    setResearchStage("idle");
  };

  // 表单提交处理
  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    // 告诉浏览器这是一个长时间运行的任务
    if ('requestIdleCallback' in window) {
      // @ts-ignore
      window.requestIdleCallback(() => {
        console.log("Preparing for long running task");
      });
    }
    
    // Reset states
    setResearchData(null);
    setSelectedDirection(null);
    setKeywordsData(null);
    setDirectionsData(null);
    setPapersData([]);
    setReportsData([]);
    setProcessingState("idle");
    setProcessMessage("");
    setError(null);
    setProcessingDirectionIndex(-1);
    setResearchStage("idle");
    
    setLoading(true);
    
    console.log("开始提交研究请求");
    
    try {
      // Use updated endpoint to support the new keyword processing flow
      const encodedTopic = encodeURIComponent(researchTopic);
      const eventSource = new EventSource(`${API_URL}/api/research/enhanced-process-stream?research_intent=${encodedTopic}`);
      
      console.log("Connecting to:", `${API_URL}/api/research/enhanced-process-stream?research_intent=${encodedTopic}`);
      
      // 设置一个安全超时（例如15分钟），强制完成
      const safetyTimeout = setTimeout(() => {
        if (loading && eventSource) {
          console.log("安全超时触发，强制完成研究");
          setProcessingState("completed");
          setProcessMessage("研究处理已完成(超时保护)");
          setResearchStage("complete");
          eventSource.close();
          setLoading(false);
        }
      }, 15 * 60 * 1000); // 15分钟
      
      // 设置一个最大处理时间（例如15分钟）
      const maxProcessingTimer = setTimeout(() => {
        if (loading && processingState !== "completed") {
          console.log("处理时间过长，自动结束");
          
          // 设置为完成状态
          setProcessingState("completed");
          setProcessMessage("研究处理已完成");
          
          if (eventSource) {
            eventSource.close();
          }
          setLoading(false);
        }
      }, 15 * 60 * 1000); // 15分钟超时
      
      // 设置一个强制更新进度的定时器，确保进度即使在没有事件的情况下也会更新
      const progressUpdateTimer = setInterval(() => {
        if (loading) {
          console.log("定时更新进度...");
          setProgress(calculateTaskBasedProgress());
        } else {
          clearInterval(progressUpdateTimer);
        }
      }, 2000); // 每2秒更新一次
      
      // Process server events
      eventSource.onmessage = (event) => {
        try {
          const data = JSON.parse(event.data);
          console.log("收到事件:", data.status, data);
          
          // 立即更新状态
          setProcessingState(data.status);
          
          switch (data.status) {
            case 'processing_keywords': {
              setProcessMessage("正在处理关键词...");
              setResearchStage("keywords");
              break;
            }
            
            case 'keywords_ready': {
              setKeywordsData(data.data);
              setProcessMessage("关键词提取完成");
              setResearchStage("topics");
              break;
            }
            
            case 'processing_directions': {
              setProcessMessage("正在生成研究方向...");
              setResearchStage("topics");
              break;
            }
            
            case 'directions_ready': {
              setDirectionsData(data.data);
              setProcessMessage("研究方向生成完成");
              setResearchStage("searching");
              
              // 初始化论文数据和报告数据数组
              const topicsCount = data.data.research_topics.length;
              setPapersData(new Array(topicsCount).fill(null));
              setReportsData(new Array(topicsCount).fill(null));
              break;
            }
            
            case 'searching_papers': {
              // 尝试以多种方式提取方向索引
              let directionIndex = -1;
              
              // 安全地检查direction_index是否存在
              if (data.data && typeof data.data.direction_index !== 'undefined') {
                directionIndex = data.data.direction_index;
              } else if (typeof data.current_direction !== 'undefined') {
                directionIndex = data.current_direction;
              } else if (typeof data.direction_index !== 'undefined') {
                directionIndex = data.direction_index;
              }
              
              // 设置方向索引（如果找到了）
              if (directionIndex >= 0) {
                setProcessMessage(`正在搜索研究方向 ${directionIndex + 1} 的相关论文...`);
                setProcessingDirectionIndex(directionIndex);
              } else {
                // 如果没有找到方向索引，使用通用消息
                setProcessMessage(`正在搜索相关论文...`);
              }
              
              // 无论如何都设置研究阶段
              setResearchStage("searching");
              break;
            }
            
            case 'papers_ready': {
              setPapersData(prev => {
                const newData = [...prev];
                if (data.data && typeof data.data.direction_index !== 'undefined') {
                  newData[data.data.direction_index] = {
                    direction: data.data.direction,
                    original_direction: data.data.original_direction,
                    search_keywords: data.data.search_keywords,
                    papers: data.data.papers
                  };
                }
                return newData;
              });
              
              if (data.data && typeof data.data.direction_index !== 'undefined') {
                setProcessMessage(`研究方向 ${data.data.direction_index + 1} 的论文检索完成`);
              } else {
                setProcessMessage(`论文检索完成`);
              }
              break;
            }
            
            case 'generating_report': {
              if (data.data && typeof data.data.direction_index !== 'undefined') {
                setProcessMessage(`正在生成研究方向 ${data.data.direction_index + 1} 的研究报告...`);
                setProcessingDirectionIndex(data.data.direction_index);
              } else {
                setProcessMessage(`正在生成研究报告...`);
              }
              setResearchStage("reporting");
              break;
            }
            
            case 'report_ready': {
              setReportsData(prev => {
                const newData = [...prev];
                if (data.data && typeof data.data.direction_index !== 'undefined') {
                  newData[data.data.direction_index] = {
                    direction: data.data.direction,
                    original_direction: data.data.original_direction,
                    search_keywords: data.data.search_keywords,
                    report: data.data.report
                  };
                  
                  // 设置当前处理的方向索引
                  setProcessingDirectionIndex(data.data.direction_index);
                  
                  // 获取当前方向索引和完成报告数量
                  const currentDirectionIndex = data.data.direction_index;
                  const validReports = newData.filter(r => r && r.report);
                  const completedReportsCount = validReports.length;
                  const allTopicsCount = directionsData?.research_topics?.length || 0;
                  
                  console.log(`研究报告生成状态: 方向${currentDirectionIndex+1}/${allTopicsCount} 已完成${completedReportsCount}个`);
                  
                  // 决定是否结束任务的条件:
                  // 1. 已经完成至少3个研究方向的报告
                  // 2. 或者已完成所有研究方向的报告
                  // 3. 或者当前是第5个研究方向(索引为4)
                  if ((completedReportsCount >= 3) || 
                      (completedReportsCount >= allTopicsCount) || 
                      (currentDirectionIndex >= 4)) {
                    
                    console.log(`已完成足够的研究方向 (${completedReportsCount}/${allTopicsCount})，结束研究流程`);
                    
                    // 构建完整的研究数据
                    const completeResearchData = {
                      research_intent: researchTopic,
                      language: keywordsData?.language || "en",
                      base_keywords: keywordsData?.keywords || [],
                      research_topics: directionsData?.research_topics || [],
                      papers_by_direction: papersData,
                      direction_reports: newData,
                      status: "completed"
                    };
                    
                    // 设置研究数据和状态
                    setResearchData(completeResearchData);
                    setResearchStage("complete");
                    setProcessingState("completed");
                    setProcessMessage("研究处理完成");
                    setProgress(100); // 强制设置进度为100%
                    
                    // 关闭连接
                    if (eventSource) {
                      try {
                        console.log("关闭EventSource连接");
                        eventSource.close();
                        setLoading(false);
                      } catch (err) {
                        console.error("关闭EventSource时出错:", err);
                        setLoading(false);
                      }
                    } else {
                      setLoading(false);
                    }
                    
                    // 调用onSubmit回调（如果提供）
                    if (onSubmit) {
                      onSubmit(completeResearchData);
                    }
                  }
                }
                
                return newData;
              });
              break;
            }
            
            case 'error': {
              setError(data.message || "处理过程中发生错误");
              eventSource.close();
              setLoading(false);
              break;
            }
            
            default: {
              console.log("收到未处理的事件类型:", data.status);
              break;
            }
          }
          
          // 更新总体进度
          setProgress(calculateTaskBasedProgress());
          
        } catch (error) {
          console.error("处理事件数据时出错:", error);
          setError("处理事件数据时出错");
          if (eventSource) {
            eventSource.close();
          }
          setLoading(false);
        }
      };
      
      // Error handling for the event source
      eventSource.onerror = (error) => {
        console.error("EventSource错误:", error);
        setError("与服务器连接时出错");
        eventSource.close();
        setLoading(false);
      };
      
    } catch (error) {
      console.error("提交请求时出错:", error);
      setError("提交请求时出错");
      setLoading(false);
    }
  };

  // 渲染研究结果组件（简化版占位符）
  const ResearchResults = ({ data }) => (
    <div className="space-y-4">
      <p className="text-white/80">研究完成！您可以查看各个研究方向的详细报告。</p>
    </div>
  );

  return (
    <div className={className}>
      {/* 研究表单 */}
      <form onSubmit={handleSubmit} className="space-y-4">
                {/* 标题和说明 */}
                <div className="mb-6">
          <h2 className="text-2xl font-bold text-white mb-2">研究助手</h2>
          <p className="text-white/70">
            输入您想研究的主题，我将帮您分析关键词、确定研究方向、搜索相关论文并生成研究报告。
          </p>
        </div>

        {/* 研究主题输入 */}
        <div className="space-y-2">
          <label htmlFor="research-topic" className="block text-sm font-medium text-white">
            研究主题
          </label>
          <textarea
            id="research-topic"
            placeholder="输入您想研究的主题，例如：新能源电池技术的最新发展及应用前景"
            className="w-full h-24 px-3 py-2 text-white bg-white/5 border border-white/10 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent"
            value={researchTopic}
            onChange={(e) => setResearchTopic(e.target.value)}
            disabled={loading}
          />
        </div>

        {/* 错误信息显示 */}
        {error && <ErrorMessage message={error} onClose={() => setError(null)} />}

        {/* 提交按钮 */}
        <div className="flex">
          <Button
            type="submit"
            disabled={!researchTopic.trim() || loading}
            className={`${
              loading ? 'bg-blue-600/50' : 'bg-blue-600 hover:bg-blue-700'
            } text-white font-medium py-2 px-4 rounded-md transition-colors`}
          >
            {loading ? "研究进行中..." : "开始研究"}
          </Button>

          {loading && (
            <button
              type="button"
              onClick={() => window.location.reload()}
              className="ml-2 text-white/60 hover:text-white text-sm"
            >
              取消
            </button>
          )}
        </div>
      </form>

      {/* 处理中状态显示 */}
      {loading && (
        <div className="mt-8 space-y-4">
          {/* 进度显示 */}
          <div className="flex justify-between items-center mb-2">
            <div className="text-sm font-medium text-white">
              {processingState === 'completed' 
                ? '研究完成' 
                : `正在处理 (${progress}%)`
              }
            </div>
            <div className="text-xs text-white/60">
              {processMessage}
            </div>
          </div>

          {/* 进度条 */}
          <div className="w-full bg-white/10 rounded-full h-2.5 mb-6">
            <div
              className="bg-blue-600 h-2.5 rounded-full transition-all duration-500"
              style={{
                width: `${progress}%`,
              }}
            ></div>
          </div>

          {/* 研究进度步骤组件 */}
          <ResearchProgressBar />

          {/* 详细研究进度 */}
          <ResearchProgressDisplay />
        </div>
      )}

      {/* 研究结果显示 */}
      {researchData && !loading && (
        <div className="mt-8">
          <ResearchResults data={researchData} />
          
          {/* 研究进度详情 */}
          <ResearchProgressDisplay />
          
          {/* 导出按钮 */}
          {onExport && (
            <Button
              onClick={() => onExport(researchData)}
              className="mt-4 bg-green-600 hover:bg-green-700 text-white font-medium py-2 px-4 rounded-md transition-colors"
            >
              导出研究结果
            </Button>
          )}
          
          {/* 重置按钮 */}
          <Button
            onClick={resetForm}
            className="mt-4 ml-2 bg-gray-600 hover:bg-gray-700 text-white font-medium py-2 px-4 rounded-md transition-colors"
          >
            开始新研究
          </Button>
        </div>
      )}
      
      {/* 模态框 */}
      <PapersModal />
    </div>
  );
}